==> onednn-1.7-1-x86_64.pkg.tar.zst: usr/share/doc/dnnl/reference/html/group__dnnl__api__service.js <==
var group__dnnl__api__service =
[
    [ "dnnl_version_t", "structdnnl__version__t.html", [
      [ "major", "structdnnl__version__t.html#ab0051e104a0b84b25c22f2ed98a9a16c", null ],
      [ "minor", "structdnnl__version__t.html#a30f17c81ffa45f1929bbe4f2c14fe42f", null ],
      [ "patch", "structdnnl__version__t.html#aa29d1e7545c879cafc88426086443d1b", null ],
      [ "hash", "structdnnl__version__t.html#a1c2a7e8b3f26ed376b537dd511feccad", null ],
      [ "cpu_runtime", "structdnnl__version__t.html#a2d0bade7e7ab7ff25d68f9011a3978e2", null ],
      [ "gpu_runtime", "structdnnl__version__t.html#ac15e5566f96a65b2c97903c787f129ac", null ]
    ] ],
    [ "DNNL_RUNTIME_NONE", "group__dnnl__api__service.html#ga64c87a04eba7774b2157dc6ce95d5992", null ],
    [ "DNNL_RUNTIME_SEQ", "group__dnnl__api__service.html#ga01fabb77bdc210ee4934de063f22d553", null ],
    [ "DNNL_RUNTIME_OMP", "group__dnnl__api__service.html#ga457c36c7619dbb25cc75feef3febc2e3", null ],
    [ "DNNL_RUNTIME_TBB", "group__dnnl__api__service.html#ga9c5fbce1bd3d780a088a34e90fbb4e4f", null ],
    [ "DNNL_RUNTIME_THREADPOOL", "group__dnnl__api__service.html#gab830f5937d97d4fc2a7dd09d84f43873", null ],
    [ "DNNL_RUNTIME_OCL", "group__dnnl__api__service.html#ga2e98ba1f2fa907d8b11b009fecae32da", null ],
    [ "DNNL_JIT_PROFILE_NONE", "group__dnnl__api__service.html#ga7ceacd6430988ed4bf58f5b01cd9c5a4", null ],
    [ "DNNL_JIT_PROFILE_VTUNE", "group__dnnl__api__service.html#ga137013d98ef736973ebbe1ecd4a4b2c9", null ],
    [ "DNNL_JIT_PROFILE_LINUX_PERFMAP", "group__dnnl__api__service.html#gacb5b174589525cce34589ef4ef56462f", null ],
    [ "DNNL_JIT_PROFILE_LINUX_JITDUMP", "group__dnnl__api__service.html#ga5afb7d615d8507b8d5469553e6dde2a7", null ],
    [ "DNNL_JIT_PROFILE_LINUX_JITDUMP_USE_TSC", "group__dnnl__api__service.html#ga66a48a940ab2916d360b0bb677a70e5f", null ],
    [ "DNNL_JIT_PROFILE_LINUX_PERF", "group__dnnl__api__service.html#ga5a1d61af9d5b15dbc6d7d33f0f3e22bc", null ],
    [ "version_t", "group__dnnl__api__service.html#ga7b6ec8722f5ad94170755b8be0cdd3af", null ],
    [ "status", "group__dnnl__api__service.html#ga7acc4d3516304ae68a1289551d8f2cdd", [
      [ "success", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda260ca9dd8a4577fc00b7bd5810298076", null ],
      [ "out_of_memory", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda5ea42cc8dbd653d9afd96c1d2fd147e2", null ],
      [ "invalid_arguments", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda242ac674d98ee2191f0bbf6de851d2d0", null ],
      [ "unimplemented", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda4316423dfe3ade85c292aa38185f9817", null ],
      [ "iterator_ends", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cddaeea82822a38c56f5e03aae6ae1775adb", null ],
      [ "runtime_error", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda5b32065884bcc1f2ed126c47e6410808", null ],
      [ "not_required", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda20ab085a3c46af7db87fc1806865b329", null ]
    ] ],
    [ "cpu_isa", "group__dnnl__api__service.html#gabad017feb1850634bf3babdb68234f83", [
      [ "all", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aa181a603769c1f98ad927e7367c7aa51", null ],
      [ "sse41", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83ab14e8c38c0a37f70c070f2a862d30d65", null ],
      [ "avx", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a73758c37e4499f20ac5f995a144abba6", null ],
      [ "avx2", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a220c4ad92e33497ef256a48712352b84", null ],
      [ "avx512_mic", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a046d44270c4d1f4f1c76ae337c97ccf3", null ],
      [ "avx512_mic_4ops", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aad1ffde9d0e65a434da74d86c82f1edd", null ],
      [ "avx512_core", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aa427cc9f00ac692056a83a8cb5e37fa4", null ],
      [ "avx512_core_vnni", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83acac6fe12844735aafd8fd1fd81738f8e", null ],
      [ "avx512_core_bf16", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83af9b353b49d5aa4dfe76e22337b5a02cf", null ],
      [ "avx512_core_amx", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83ad49189665b06a3259b3bf3603319fd0d", null ]
    ] ],
    [ "dnnl_cpu_isa_t", "group__dnnl__api__service.html#ga303bab5d2e7b371bb44495864df21dd2", [
      [ "dnnl_cpu_isa_all", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a4f614e9d72ffc6338fdfc420b77601c8", null ],
      [ "dnnl_cpu_isa_sse41", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a5e2f2cccadb94b34700a90bba91e0fe3", null ],
      [ "dnnl_cpu_isa_avx", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a270db093c67689e8e926afffc16706a2", null ],
      [ "dnnl_cpu_isa_avx2", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a45f38960497cf614c1adfffddaa57032", null ],
      [ "dnnl_cpu_isa_avx512_mic", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a0929d2af13de542102f0d47776023164", null ],
      [ "dnnl_cpu_isa_avx512_mic_4ops", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2ad30d60a53b03395ab914e685656436e2", null ],
      [ "dnnl_cpu_isa_avx512_core", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a574f09a9b057ba134d48dadf6d8aa201", null ],
      [ "dnnl_cpu_isa_avx512_core_vnni", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a3aced59a3047f7e407b1fe3310430554", null ],
      [ "dnnl_cpu_isa_avx512_core_bf16", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a9ced36845ccb9a8dd63cd49ec103412b", null ],
      [ "dnnl_cpu_isa_avx512_core_amx", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a3a4b0c594f109982fde90e221087ded9", null ]
    ] ],
    [ "dnnl_set_verbose", "group__dnnl__api__service.html#ga14cc3b56337322e1e5132c5ee0c84856", null ],
    [ "dnnl_set_jit_dump", "group__dnnl__api__service.html#ga03c8f4af3d01f76060f98e78039837fc", null ],
    [ "dnnl_version", "group__dnnl__api__service.html#ga3a5fbaf64f33c4d9b96816f6976bcaf9", null ],
    [ "dnnl_set_jit_profiling_flags", "group__dnnl__api__service.html#ga51ef634e4f201a12d32e573955943f48", null ],
    [ "dnnl_set_jit_profiling_jitdumpdir", "group__dnnl__api__service.html#gafb0fb0d37d72bc58386ba97bb858f8f7", null ],
    [ "dnnl_set_max_cpu_isa", "group__dnnl__api__service.html#ga4b7f3b3299482f88f1a0aa61a4707156", null ],
    [ "dnnl_get_effective_cpu_isa", "group__dnnl__api__service.html#gac55836cf36bc25f8635e459678303570", null ],
    [ "set_verbose", "group__dnnl__api__service.html#ga37bcab6f832df551a9fc418e48743b15", null ],
    [ "version", "group__dnnl__api__service.html#gaad8292408620d0296f22bdf65afb752d", null ],
    [ "set_jit_dump", "group__dnnl__api__service.html#ga2344639528a341878d2ce46fe1c1ac83", null ],
    [ "set_jit_profiling_flags", "group__dnnl__api__service.html#ga966c54ccb1d9ff33d20c4ea47e34675d", null ],
    [ "set_jit_profiling_jitdumpdir", "group__dnnl__api__service.html#ga533341aaf1402e27d1225d1a59819a62", null ],
    [ "set_max_cpu_isa", "group__dnnl__api__service.html#ga08734310b5f1ca794c64b6a5b944b698", null ],
    [ "get_effective_cpu_isa", "group__dnnl__api__service.html#ga3953f71c3f0126d9cc005a1ceff65e8b", null ]
];

==> onednn-1.8-1-x86_64.pkg.tar.zst: usr/share/doc/dnnl/reference/html/group__dnnl__api__service.js <==
var group__dnnl__api__service =
[
    [ "dnnl_version_t", "structdnnl__version__t.html", [
      [ "major", "structdnnl__version__t.html#ab0051e104a0b84b25c22f2ed98a9a16c", null ],
      [ "minor", "structdnnl__version__t.html#a30f17c81ffa45f1929bbe4f2c14fe42f", null ],
      [ "patch", "structdnnl__version__t.html#aa29d1e7545c879cafc88426086443d1b", null ],
      [ "hash", "structdnnl__version__t.html#a1c2a7e8b3f26ed376b537dd511feccad", null ],
      [ "cpu_runtime", "structdnnl__version__t.html#a2d0bade7e7ab7ff25d68f9011a3978e2", null ],
      [ "gpu_runtime", "structdnnl__version__t.html#ac15e5566f96a65b2c97903c787f129ac", null ]
    ] ],
    [ "DNNL_RUNTIME_NONE", "group__dnnl__api__service.html#ga64c87a04eba7774b2157dc6ce95d5992", null ],
    [ "DNNL_RUNTIME_SEQ", "group__dnnl__api__service.html#ga01fabb77bdc210ee4934de063f22d553", null ],
    [ "DNNL_RUNTIME_OMP", "group__dnnl__api__service.html#ga457c36c7619dbb25cc75feef3febc2e3", null ],
    [ "DNNL_RUNTIME_TBB", "group__dnnl__api__service.html#ga9c5fbce1bd3d780a088a34e90fbb4e4f", null ],
    [ "DNNL_RUNTIME_THREADPOOL", "group__dnnl__api__service.html#gab830f5937d97d4fc2a7dd09d84f43873", null ],
    [ "DNNL_RUNTIME_OCL", "group__dnnl__api__service.html#ga2e98ba1f2fa907d8b11b009fecae32da", null ],
    [ "DNNL_JIT_PROFILE_NONE", "group__dnnl__api__service.html#ga7ceacd6430988ed4bf58f5b01cd9c5a4", null ],
    [ "DNNL_JIT_PROFILE_VTUNE", "group__dnnl__api__service.html#ga137013d98ef736973ebbe1ecd4a4b2c9", null ],
    [ "DNNL_JIT_PROFILE_LINUX_PERFMAP", "group__dnnl__api__service.html#gacb5b174589525cce34589ef4ef56462f", null ],
    [ "DNNL_JIT_PROFILE_LINUX_JITDUMP", "group__dnnl__api__service.html#ga5afb7d615d8507b8d5469553e6dde2a7", null ],
    [ "DNNL_JIT_PROFILE_LINUX_JITDUMP_USE_TSC", "group__dnnl__api__service.html#ga66a48a940ab2916d360b0bb677a70e5f", null ],
    [ "DNNL_JIT_PROFILE_LINUX_PERF", "group__dnnl__api__service.html#ga5a1d61af9d5b15dbc6d7d33f0f3e22bc", null ],
    [ "version_t", "group__dnnl__api__service.html#ga7b6ec8722f5ad94170755b8be0cdd3af", null ],
    [ "status", "group__dnnl__api__service.html#ga7acc4d3516304ae68a1289551d8f2cdd", [
      [ "success", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda260ca9dd8a4577fc00b7bd5810298076", null ],
      [ "out_of_memory", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda5ea42cc8dbd653d9afd96c1d2fd147e2", null ],
      [ "invalid_arguments", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda242ac674d98ee2191f0bbf6de851d2d0", null ],
      [ "unimplemented", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda4316423dfe3ade85c292aa38185f9817", null ],
      [ "iterator_ends", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cddaeea82822a38c56f5e03aae6ae1775adb", null ],
      [ "runtime_error", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda5b32065884bcc1f2ed126c47e6410808", null ],
      [ "not_required", "group__dnnl__api__service.html#gga7acc4d3516304ae68a1289551d8f2cdda20ab085a3c46af7db87fc1806865b329", null ]
    ] ],
    [ "cpu_isa", "group__dnnl__api__service.html#gabad017feb1850634bf3babdb68234f83", [
      [ "all", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aa181a603769c1f98ad927e7367c7aa51", null ],
      [ "sse41", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83ab14e8c38c0a37f70c070f2a862d30d65", null ],
      [ "avx", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a73758c37e4499f20ac5f995a144abba6", null ],
      [ "avx2", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a220c4ad92e33497ef256a48712352b84", null ],
      [ "avx512_mic", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a046d44270c4d1f4f1c76ae337c97ccf3", null ],
      [ "avx512_mic_4ops", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aad1ffde9d0e65a434da74d86c82f1edd", null ],
      [ "avx512_core", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aa427cc9f00ac692056a83a8cb5e37fa4", null ],
      [ "avx512_core_vnni", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83acac6fe12844735aafd8fd1fd81738f8e", null ],
      [ "avx512_core_bf16", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83af9b353b49d5aa4dfe76e22337b5a02cf", null ],
      [ "avx512_core_amx", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83ad49189665b06a3259b3bf3603319fd0d", null ],
      [ "avx2_vnni", "group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a59548f83cb32f5f6272186734a9a711d", null ]
    ] ],
    [ "dnnl_cpu_isa_t", "group__dnnl__api__service.html#ga303bab5d2e7b371bb44495864df21dd2", [
      [ "dnnl_cpu_isa_all", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a4f614e9d72ffc6338fdfc420b77601c8", null ],
      [ "dnnl_cpu_isa_sse41", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a5e2f2cccadb94b34700a90bba91e0fe3", null ],
      [ "dnnl_cpu_isa_avx", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a270db093c67689e8e926afffc16706a2", null ],
      [ "dnnl_cpu_isa_avx2", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a45f38960497cf614c1adfffddaa57032", null ],
      [ "dnnl_cpu_isa_avx512_mic", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a0929d2af13de542102f0d47776023164", null ],
      [ "dnnl_cpu_isa_avx512_mic_4ops", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2ad30d60a53b03395ab914e685656436e2", null ],
      [ "dnnl_cpu_isa_avx512_core", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a574f09a9b057ba134d48dadf6d8aa201", null ],
      [ "dnnl_cpu_isa_avx512_core_vnni", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a3aced59a3047f7e407b1fe3310430554", null ],
      [ "dnnl_cpu_isa_avx512_core_bf16", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a9ced36845ccb9a8dd63cd49ec103412b", null ],
      [ "dnnl_cpu_isa_avx512_core_amx", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a3a4b0c594f109982fde90e221087ded9", null ],
      [ "dnnl_cpu_isa_avx2_vnni", "group__dnnl__api__service.html#gga303bab5d2e7b371bb44495864df21dd2a8f2cbdae2834cebd2e5bf86b8c65e9d4", null ]
    ] ],
    [ "dnnl_set_verbose", "group__dnnl__api__service.html#ga14cc3b56337322e1e5132c5ee0c84856", null ],
    [ "dnnl_set_jit_dump", "group__dnnl__api__service.html#ga03c8f4af3d01f76060f98e78039837fc", null ],
    [ "dnnl_version", "group__dnnl__api__service.html#ga3a5fbaf64f33c4d9b96816f6976bcaf9", null ],
    [ "dnnl_set_jit_profiling_flags", "group__dnnl__api__service.html#ga51ef634e4f201a12d32e573955943f48", null ],
    [ "dnnl_set_jit_profiling_jitdumpdir", "group__dnnl__api__service.html#gafb0fb0d37d72bc58386ba97bb858f8f7", null ],
    [ "dnnl_set_max_cpu_isa", "group__dnnl__api__service.html#ga4b7f3b3299482f88f1a0aa61a4707156", null ],
    [ "dnnl_get_effective_cpu_isa", "group__dnnl__api__service.html#gac55836cf36bc25f8635e459678303570", null ],
    [ "set_verbose", "group__dnnl__api__service.html#ga37bcab6f832df551a9fc418e48743b15", null ],
    [ "version", "group__dnnl__api__service.html#gaad8292408620d0296f22bdf65afb752d", null ],
    [ "set_jit_dump", "group__dnnl__api__service.html#ga2344639528a341878d2ce46fe1c1ac83", null ],
    [ "set_jit_profiling_flags", "group__dnnl__api__service.html#ga966c54ccb1d9ff33d20c4ea47e34675d", null ],
    [ "set_jit_profiling_jitdumpdir", "group__dnnl__api__service.html#ga533341aaf1402e27d1225d1a59819a62", null ],
    [ "set_max_cpu_isa", "group__dnnl__api__service.html#ga08734310b5f1ca794c64b6a5b944b698", null ],
    [ "get_effective_cpu_isa", "group__dnnl__api__service.html#ga3953f71c3f0126d9cc005a1ceff65e8b", null ]
];
